==> gatsby-theme-backend-1.0.0.tgz: package/src/components/Layout.js <==
import React from "react"
import ThemeContext from "../context/ThemeContext"
import { IntlProvider } from "react-intl"
import LangSwitcher from "./Backend/LangSwitcher"
import { DefaultFooter } from "@ant-design/pro-layout"
import { Link } from "gatsby"
import { ConfigProvider } from "antd"
import enUS from "antd/lib/locale/en_US"
import thTH from "antd/lib/locale/th_TH"
import zhCN from "antd/lib/locale/zh_CN"
import enMessages from "../messages/en.json"
import thMessages from "../messages/th.json"
import zhMessages from "../messages/zh.json"
import logo from "../../static/images/logo.svg"
import "./Layout.less"
import { FacebookFilled } from "@ant-design/icons"

const intlMap = {
	enUS,
	thTH,
	zhCN,
}
const messagesMap = {
	enMessages,
	thMessages,
	zhMessages,
}

const Layout = ({ children }) => (
	<ThemeContext.Consumer>
		{({ currentLang, currentLocale, currentMessage }) => (
			<IntlProvider
				locale={currentLocale}
				messages={messagesMap[currentMessage]}
			>
				<ConfigProvider locale={intlMap[currentLang]}>
					<div className="container">
						<div className="languagesContainer">
							<LangSwitcher />
						</div>
						<div className="content">
							<div className="top">
								<div className="header">
									<Link to="/">
										<img alt="logo" className="logo" src={logo} />
										<span className="title">Deeboon Backend</span>
									</Link>
								</div>
								<div className="desc">
									The modern cms for Deeboon's clients.
								</div>
							</div>
							{children}
						</div>
						<DefaultFooter
							copyright={`${new Date().getFullYear()} Deeboon Part., Ltd.`}
							links={[
								{
									key: "websitecafe",
									title: "Websitecafe",
									href: "https://websitecafe.co/",
									blankTarget: true,
								},
								{
									key: "facebook",
									title: <FacebookFilled />,
									href: "https://web.facebook.com/websitecafe2003",
									blankTarget: true,
								},
								{
									key: "deeboon",
									title: "Deeboon",
									href: "https://www.deeboon.co.th/",
									blankTarget: true,
								},
							]}
						/>
					</div>
				</ConfigProvider>
			</IntlProvider>
		)}
	</ThemeContext.Consumer>
)

export default Layout

==> gatsby-theme-backend-1.0.6.tgz: package/src/components/Layout.js <==
import React from "react"
import ThemeContext from "../context/ThemeContext"
import { IntlProvider } from "react-intl"
import LangSwitcher from "./Backend/LangSwitcher"
import { Link } from "gatsby"
import { ConfigProvider } from "antd"
import enUS from "antd/lib/locale/en_US"
import thTH from "antd/lib/locale/th_TH"
import zhCN from "antd/lib/locale/zh_CN"
import enMessages from "../messages/en.json"
import thMessages from "../messages/th.json"
import zhMessages from "../messages/zh.json"
import logo from "../../static/images/logo.svg"
import "./Layout.less"

const intlMap = {
	enUS,
	thTH,
	zhCN,
}
const messagesMap = {
	enMessages,
	thMessages,
	zhMessages,
}

const Layout = ({ children }) => (
	<ThemeContext.Consumer>
		{({ currentLang, currentLocale, currentMessage }) => (
			<IntlProvider
				locale={currentLocale}
				messages={messagesMap[currentMessage]}
			>
				<ConfigProvider locale={intlMap[currentLang]}>
					<div className="container">
						<div className="languagesContainer">
							<LangSwitcher />
						</div>
						<div className="content">
							<div className="top">
								<div className="header">
									<Link to="/">
										<img alt="logo" className="logo" src={logo} />
										<span className="title">Modern Backend</span>
									</Link>
								</div>
								<div className="desc">The modern cms for you.</div>
							</div>
							{children}
						</div>
					</div>
				</ConfigProvider>
			</IntlProvider>
		)}
	</ThemeContext.Consumer>
)

export default Layout
